==> haskell-filepattern-0.1.1-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-filepattern.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: filepattern
version: 0.1.1
id: filepattern-0.1.1-JKaHFIOtL7OKyDNHTx4Xrg
key: filepattern-0.1.1-JKaHFIOtL7OKyDNHTx4Xrg
license: BSD-3-Clause
copyright: Neil Mitchell 2011-2019
maintainer: Neil Mitchell <ndmitchell@gmail.com>
author: Neil Mitchell <ndmitchell@gmail.com>, Evan Rutledge Borden <evan@evan-borden.com>
homepage: https://github.com/ndmitchell/filepattern#readme
synopsis: File path glob-like matching
description:
    A library for matching files using patterns such as @\"src\/**\/*.png\"@ for all @.png@ files
    recursively under the @src@ directory. Features:
    .
    * All matching is /O(n)/.
    .
    * See "System.FilePattern" and @?==@ simple matching and semantics.
    .
    * Use @match@ and @substitute@ to extract suitable
    strings from the @*@ and @**@ matches, and substitute them back into other patterns.
    .
    * Use @step@ and @matchMany@ to perform bulk matching
    of many patterns against many paths simultaneously.
    .
    * Use "System.FilePattern.Directory" to perform optimised directory traverals using patterns.
    .
    Originally taken from the <https://hackage.haskell.org/package/shake Shake library>.
category: Development, FilePath
abi: 261304d4279b54ceb41ad0ad438e9285
exposed: True
exposed-modules:
    System.FilePattern System.FilePattern.Directory
hidden-modules: System.FilePattern.Core System.FilePattern.ListBy
                System.FilePattern.Monads System.FilePattern.Step
                System.FilePattern.Tree System.FilePattern.Wildcard
import-dirs: /usr/lib/ghc-8.6.5/site-local/filepattern-0.1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/filepattern-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/filepattern-0.1.1
hs-libraries: HSfilepattern-0.1.1-JKaHFIOtL7OKyDNHTx4Xrg
depends:
    base-4.12.0.0 directory-1.3.3.0 extra-1.6.17-Az2MbiNeCcF2FHZyOjEOm
    filepath-1.4.2.1
haddock-interfaces: /usr/share/doc/haskell-filepattern/html/filepattern.haddock
haddock-html: /usr/share/doc/haskell-filepattern/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-filepattern-0.1.1-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-filepattern.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: filepattern
version: 0.1.1
id: filepattern-0.1.1-BHuCCmNi0Tx5h2B0RqbDkw
key: filepattern-0.1.1-BHuCCmNi0Tx5h2B0RqbDkw
license: BSD-3-Clause
copyright: Neil Mitchell 2011-2019
maintainer: Neil Mitchell <ndmitchell@gmail.com>
author: Neil Mitchell <ndmitchell@gmail.com>, Evan Rutledge Borden <evan@evan-borden.com>
homepage: https://github.com/ndmitchell/filepattern#readme
synopsis: File path glob-like matching
description:
    A library for matching files using patterns such as @\"src\/**\/*.png\"@ for all @.png@ files
    recursively under the @src@ directory. Features:
    .
    * All matching is /O(n)/.
    .
    * See "System.FilePattern" and @?==@ simple matching and semantics.
    .
    * Use @match@ and @substitute@ to extract suitable
    strings from the @*@ and @**@ matches, and substitute them back into other patterns.
    .
    * Use @step@ and @matchMany@ to perform bulk matching
    of many patterns against many paths simultaneously.
    .
    * Use "System.FilePattern.Directory" to perform optimised directory traverals using patterns.
    .
    Originally taken from the <https://hackage.haskell.org/package/shake Shake library>.
category: Development, FilePath
abi: 570fc5aea86ea85048a7552abb12ba4e
exposed: True
exposed-modules:
    System.FilePattern System.FilePattern.Directory
hidden-modules: System.FilePattern.Core System.FilePattern.ListBy
                System.FilePattern.Monads System.FilePattern.Step
                System.FilePattern.Tree System.FilePattern.Wildcard
import-dirs: /usr/lib/ghc-8.6.5/site-local/filepattern-0.1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/filepattern-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/filepattern-0.1.1
hs-libraries: HSfilepattern-0.1.1-BHuCCmNi0Tx5h2B0RqbDkw
depends:
    base-4.12.0.0 directory-1.3.3.0 extra-1.6.17-GS5yEZst6rmATRRpZlUQ12
    filepath-1.4.2.1
haddock-interfaces: /usr/share/doc/haskell-filepattern/html/filepattern.haddock
haddock-html: /usr/share/doc/haskell-filepattern/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
